#
# spec file for package molsketch
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define srcname Molsketch
%define sover 1
%define soname -qt5-%{sover}
%define binname %{name}-qt5
Name:           molsketch
Version:        0.7.0
Release:        bp154.1.41
Summary:        2D molecular structures editor
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Chemistry
URL:            https://molsketch.sourceforge.net
Source0:        https://downloads.sourceforge.net/molsketch/Molsketch-%{version}-src.tar.gz
# PATCH-FIX-UPSTREAM https://sourceforge.net/p/molsketch/bugs/40/
Patch0:         fix-compilation.patch
BuildRequires:  cmake
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
%if 0%{suse_version} >= 1550 || 0%{?sle_version} >= 150200
BuildRequires:  rsvg-convert
%else
BuildRequires:  rsvg-view
%endif
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Core) >= 5.2.0
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(openbabel-2.0)

%description
The purpose of this editor to help drawing molecules.
Features:
 * open, save and import in all formats supported by the OpenBabel library
 * export to Scalable Vector Graphics (SVG) and a number of common used bitmap
   formats
 * print and export your document to PDF

%package 	devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Provides:       lib%{name}%{soname} =  %{version}
Requires:       libqt5-qttools

%description 	devel
2D molecular structures editor.

This package contains header files and libraries needed to develop
application that use %{name}.

%package        doc
Summary:        Documentation for %{name}
Group:          Documentation/HTML
BuildArch:      noarch

%description    doc
2D molecular structures editor.

Help documentation for %{name}.

%prep
%autosetup -n %{srcname}-%{version} -p1
dos2unix -k -c ascii doc/cs/%{name}.adp

%build
%cmake \
  -DMSK_INSTALL_DOCS="/share/doc/packages/%{name}"

%cmake_build

%install
%cmake_install

# Fix program not finding its shared libraries.
mv %{buildroot}%{_libdir}/%{name}/libmolsketch-qt5.so %{buildroot}%{_libdir}/libmolsketch-qt5.so
mv %{buildroot}%{_libdir}/%{name}/libobabeliface-qt5.so %{buildroot}%{_libdir}/libobabeliface-qt5.so

for sz in 24 32 48 64 128 256 512
do
  rsvg-convert -o %{name}-${sz}.png -w ${sz} molsketch/images/molsketch.svg
  mkdir -p %{buildroot}%{_datadir}/icons/hicolor/${sz}x${sz}/apps
  install -m0644 %{name}-${sz}.png %{buildroot}%{_datadir}/icons/hicolor/${sz}x${sz}/apps/%{name}.png
done

%suse_update_desktop_file -c %{name} %{name} "2D molecular structures editor" %{binname} %{name} Education Chemistry

%fdupes -s %{buildroot}%{_datadir}

%files
%license COPYING
%doc CHANGELOG
%{_bindir}/%{binname}
%{_libdir}/*.so
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/molsketch.*
%{_datadir}/pixmaps/molsketch.xpm
%{_datadir}/icons/hicolor/scalable/mimetypes/*.svg
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/net.sourceforge.molsketch.appdata.xml
%{_datadir}/mime/packages/molsketch.xml

%files devel
%{_includedir}/lib%{name}/

%files doc
%{_docdir}/%{name}/
%exclude %{_docdir}/molsketch/CHANGELOG

%changelog
* Sat Jan 23 2021 Matthias Mailänder <mailaender@opensuse.org>
- Put essential libraries in the main package
* Sat Jan  2 2021 Matthias Mailänder <mailaender@opensuse.org>
- Update to version 0.7.0
  * New localizations: Greek, German, and Chinese
  * Direction of attached hydrogen atoms can be set explicitly by user
  * Atom shape can also be a circle instead of a rectangle
  * Bitmap export with adjustable resolution
  * Support OpenBabel 3
  * Fixes for sum formula and molecule tooltip
  * Fix clipping of bonds
  * Fixed OpenBabel support
- Add fix-compilation.patch
* Thu May  7 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.6.0:
  * Levels on which items are drawn are accessible; bonds are
    indicated to cover other bonds if on higher level
  * Broken bond indicator with same color as rest of bond
  * Show sum formula of molecule during hover and after selection
  * Closable wiki query
  * Improved performance for drag-and-drop insertion of molecules
  * Associated *.msm files with Molsketch
  * Fixed crashes after undo/redo (changed linkage between
    molecule, bonds, atoms)
  * Fixed global preferences (accidentally had no effect)
  * Fixed number of hydrogens and charge in saving/loading
    molecules
- Update options passed to cmake to keep up with upstream changes;
  omit MSK_INSTALL_LIBS specification entrirely since specifying
  it leads to installation of *.so into a subdir for x86_64 and
  directly into %%{_lib} for i586.
- Force ascii mode when using dos2unix.
- Drop conditionals for obsolete openSUSE versions.
- Drop shared lib package: versioned shared libraries are no
  longer installed, so everything is packaged in -devel.
* Thu Feb 20 2020 Max Lin <mlin@suse.com>
- Leap 15.2 and SLE15 SP2 has newer librsvg, extend the conditional
  for "BuildRequires: rsvg-convert"
* Wed Oct 23 2019 ro@suse.de
- fix build-requires for factory/tumbleweed
  rsvg-convert tool is now in rsvg-convert package
* Tue Jan  9 2018 badshah400@gmail.com
- Update to version 0.5.1.
  * Newman radius of atom to draw Newman-type projections.
  * New tools for aligning, spacing, and cleaning up molecules.
  * Better encapsulate calls to OpenBabel to avoid crashes.
  * Several fixes to qmake/cmake installation of files (including
    MIME types).
- Drop molsketch-cmake-incorrect-file-loc.patch: incorporated
  upstream.
- Use rsvg-convert instead of inkscape for the svg-to-png
  conversion of icons; reduces the large number of build
  dependencies otherwise required for inkscape alone.
- Only run post(un) scriptlets for openSUSE <= 1320; for newer
  openSUSE these are automatically taken care of by rpm triggers;
  where applicable also run mime_database_post(un) as part of
  these scriptlets since molsketch now installs a mime file.
* Fri Dec 29 2017 jengelh@inai.de
- Trim (tm) symbol. Trim filler wording from description.
* Mon Oct  9 2017 badshah400@gmail.com
- Update to version 0.5.0:
  * Change log displayed on startup.
  * Lone pairs and radical electrons.
  * Selection by type (not yet really useful as properties are
    usually edited only for single items).
  * Querying Wikidata for chemical structures (requires
    OpenBabel and InChI support).
- Add molsketch-cmake-incorrect-file-loc.patch: Fix cmake install
  command looking for files in molsketch/src/* whereas they have
  been moved to molsketch/* already
- Build against Qt5 unconditionally (the minimum Qt5 is available
  across all supported openSUSE versions).
- Adapt file list for update: include files no longer installed
* Thu Aug 17 2017 badshah400@gmail.com
- Update to 0.4.1:
  * A new text tool.
  * Cmake build now offers the option to turn off OpenBabel
    support, which was previously only possible with qmake.
  * Legacy stereo bonds (from files created with versions prior to
    Lithium) are now imported correctly.
- Use inkscape to build hicolor png icons from bundled svg image
  and install then all.
- Run post install scripts to update desktop database and hicolor
  icon theme.
- Run spec-cleaner for a clean-up.
* Thu Oct 22 2015 avvissu@yandex.ru
- Update to 0.3.0:
  * see: /usr/share/doc/packages/molsketch/CHANGELOG
- Create a new spec file for building RPM
- Use qmake instead of cmake
- Add new packages: libmolsketch, molsketch-doc, molsketch-devel
* Sat Jul  7 2012 scorot@free.fr
- fix build on SLE 11
* Sat Jul  7 2012 scorot@free.fr
- fix openbabel dependency according to package name changes
* Sat Feb 25 2012 mailaender@opensuse.org
- update to version 2.0.0 with fixes from git by the developer
* Tue Feb 21 2012 mailaender@opensuse.org
- initial packaging, added QtAssistant include path to CMakeLists.txt
- added BuildRequires: -post-build-checks because of compiler warnings
